@@ -52,6 +52,62 @@ int posread_chunk(FILE *f, realT **p, realT fact, int np, int nread){
   return ntoread;
 }
 
+int posread_isol(char *posfile, float ***p, float fact, int *np, int *npreal) {
+
+  FILE *pos;
+  int dum,d,i;
+  float xt,yt,zt;
+  int npread, npreadreal;
+  float xmin,xmax,ymin,ymax,zmin,zmax;
+
+  pos = fopen(posfile, "r");
+  if (pos == NULL) {
+    printf("Unable to open position file %s\n\n",posfile);
+    exit(0);
+  }
+
+  /* Read number of particles */
+  if (fscanf(pos,"%d%d\n",&npread,&npreadreal) != 2) {
+    printf("Problem reading no. particles\n");
+    exit(0);
+  }
+
+  /* Allocate the arrays */
+  (*p) = (float **)malloc(npread*sizeof(float *));
+  /* Fill the arrays */
+  for (i=0; (fscanf(pos,"%f%f%f\n",&xt,&yt,&zt) == 3); i++) {
+    if (i >= npread) {
+      printf("More particles in %s than first line claims!  Exiting.\n\n",posfile);
+      exit(0);
+    }
+    (*p)[i] = (float *)malloc(3*sizeof(float));
+    if ((*p)[i] == NULL) {
+      printf("Unable to allocate particle array in readfiles!\n");
+      fflush(stdout);
+      exit(0);
+    }
+    (*p)[i][0]=xt*fact; (*p)[i][1]=yt*fact; (*p)[i][2] = zt*fact;
+  }
+  fclose(pos);
+  printf("%d\n",i);
+  if (npread != i) {
+    printf("Read %d particles (not %d, as the first line claims)!  Exiting.\n\n", i, npread);
+    exit(0);
+  }
+  /* Test range -- can comment out */
+  xmin = BF; xmax = -BF; ymin = BF; ymax = -BF; zmin = BF; zmax = -BF;
+  for (i=0; i<npread;i++) {
+    if ((*p)[i][0]<xmin) xmin = (*p)[i][0]; if ((*p)[i][0]>xmax) xmax = (*p)[i][0];
+    if ((*p)[i][1]<ymin) ymin = (*p)[i][1]; if ((*p)[i][1]>ymax) ymax = (*p)[i][1];
+    if ((*p)[i][2]<zmin) zmin = (*p)[i][2]; if ((*p)[i][2]>zmax) zmax = (*p)[i][2];
+  }
+  printf("npread: %d, x: %f,%f; y: %f,%f; z: %f,%f\n",npread,xmin,xmax, ymin,ymax, zmin,zmax); fflush(stdout);
+
+  *np = npread;
+  *npreal = npreadreal;
+  return(0);
+}
+
 /* Positions */
 /* Returns number of particles read */
 int posread(char *posfile, realT ***p, realT fact) {
